# -*- coding: UTF-8 -*-
"""Defaults for Germinate."""

# Copyright (c) 2011 Canonical Ltd.
#
# Germinate is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.
#
# Germinate is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Germinate; see the file COPYING.  If not, write to the Free
# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
# 02110-1301, USA.

# Where do we get up-to-date seeds from?
seeds = 'http://people.canonical.com/~ubuntu-archive/seeds/'
seeds_bzr = 'http://bazaar.launchpad.net/~ubuntu-core-dev/ubuntu-seeds/'
seeds_git = 'git://git.launchpad.net/~ubuntu-core-dev/ubuntu-seeds/+git/'
release = 'ubuntu.wily'

# If we need to download Packages.gz and/or Sources.gz, where do we get
# them from?
mirror = 'http://archive.ubuntu.com/ubuntu/'
dist = 'wily'
arch = 'i386'
